@@ -796,7 +796,7 @@ msole_prop_parse (GsfMSOleMetaDataSection *section,
 		ts = gsf_timestamp_new ();
 		gsf_timestamp_set_time (ts, ft);
 		g_value_init (res, GSF_TIMESTAMP_TYPE);
-		gsf_value_set_timestamp (res, ts);
+		gsf_timestamp_to_value (ts, res);
 		gsf_timestamp_free (ts);
 
 		ADVANCE;
@@ -1087,17 +1087,19 @@ msole_prop_cmp (gconstpointer a, gconstpointer b)
 }
 
 /**
- * gsf_msole_metadata_read :
- * @in    : #GsfInput
- * @accum : #GsfDocMetaData
+ * gsf_doc_meta_data_read_from_msole:
+ * @accum: #GsfDocMetaData
+ * @in: #GsfInput
  *
  * Read a stream formated as a set of MS OLE properties from @in and store the
  * results in @accum.
  *
+ * Since: 1.14.24
+ *
  * Returns: GError which the caller must free on error.
  **/
 GError *
-gsf_msole_metadata_read	(GsfInput *in, GsfDocMetaData *accum)
+gsf_doc_meta_data_read_from_msole (GsfDocMetaData *accum, GsfInput *in)
 {
 	guint8 const *data;
 	guint16 version;
@@ -1301,6 +1303,24 @@ gsf_msole_metadata_read	(GsfInput *in, GsfDocMetaData *accum)
 	return NULL;
 }
 
+/**
+ * gsf_msole_metadata_read: (skip)
+ * @in: #GsfInput
+ * @accum: #GsfDocMetaData
+ *
+ * Read a stream formated as a set of MS OLE properties from @in and store the
+ * results in @accum.
+ *
+ * Deprecated: 1.14.24, use gsf_doc_meta_data_read_from_msole
+ *
+ * Returns: GError which the caller must free on error.
+ **/
+GError *
+gsf_msole_metadata_read	(GsfInput *in, GsfDocMetaData *accum)
+{
+	return gsf_doc_meta_data_read_from_msole (accum, in);
+}
+
 /****************************************************************************/
 
 typedef struct {
@@ -1614,17 +1634,19 @@ cb_count_props (char const *name, GsfDocProp *prop, WritePropState *state)
 }
 
 /**
- * gsf_msole_metadata_write :
- * @out : #GsfOutput
- * @meta_data : #GsfDocMetaData
- * @doc_not_component : a kludge to differentiate DocumentSummary from Summary
+ * gsf_doc_meta_data_write_to_msole:
+ * @out: #GsfOutput
+ * @meta_data: #GsfDocMetaData
+ * @doc_not_component: a kludge to differentiate DocumentSummary from Summary
+ *
+ * Since: 1.14.24
  *
  * Returns: %TRUE on success;
  **/
 gboolean
-gsf_msole_metadata_write (GsfOutput *out,
-			  GsfDocMetaData const *meta_data,
-			  gboolean doc_not_component)
+gsf_doc_meta_data_write_to_msole (GsfDocMetaData const *meta_data,
+                                  GsfOutput *out,
+				  gboolean doc_not_component)
 {
 	static guint8 const header[] = {
 		0xfe, 0xff,	/* byte order */
@@ -1692,6 +1714,24 @@ err :
 	return success;
 }
 
+/**
+ * gsf_msole_metadata_write: (skip)
+ * @out: #GsfOutput
+ * @meta_data: #GsfDocMetaData
+ * @doc_not_component: a kludge to differentiate DocumentSummary from Summary
+ *
+ * Deprecated: 1.14.24, use gsf_doc_meta_data_write_to_msole
+ *
+ * Returns: %TRUE on success;
+ **/
+gboolean
+gsf_msole_metadata_write (GsfOutput *out,
+			  GsfDocMetaData const *meta_data,
+			  gboolean doc_not_component)
+{
+	return gsf_doc_meta_data_write_to_msole (meta_data, out, doc_not_component);
+}
+
 static struct {
 	char const *tag;
 	guint	lid;
@@ -1877,8 +1917,8 @@ static struct {
 };
 
 /**
- * gsf_msole_lid_for_language
- * @lang :
+ * gsf_msole_lid_for_language:
+ * @lang:
  *
  * Returns: the LID (Language Identifier) for the input language.
  * 	If lang is %null, return 0x0400 ("-none-"), and not 0x0000 ("no proofing")
@@ -1902,8 +1942,8 @@ gsf_msole_lid_for_language (char const *lang)
 }
 
 /**
- * gsf_msole_language_for_lid :
- * @lid :
+ * gsf_msole_language_for_lid:
+ * @lid:
  *
  * Returns: the xx_YY style string (can be just xx or xxx) for the given LID.
  * 	Return value must not be freed. If the LID is not found, is set to
@@ -1922,9 +1962,9 @@ gsf_msole_language_for_lid (guint lid)
 }
 
 /**
- * gsf_msole_locale_to_lid :
+ * gsf_msole_locale_to_lid:
  *
- * Covert the the codepage into an applicable LID
+ * Convert the the codepage into an applicable LID
  **/
 guint
 gsf_msole_codepage_to_lid (int codepage)
@@ -1967,8 +2007,8 @@ gsf_msole_codepage_to_lid (int codepage)
 }
 
 /**
- * gsf_msole_lid_to_codepage
- * @lid :
+ * gsf_msole_lid_to_codepage:
+ * @lid:
  *
  * Returns: our best guess at the codepage for the given language id
  **/
@@ -2168,8 +2208,8 @@ gsf_msole_lid_to_codepage (guint lid)
 }
 
 /**
- * gsf_msole_lid_to_codepage_str
- * @lid :
+ * gsf_msole_lid_to_codepage_str:
+ * @lid:
  *
  * Returns: the Iconv codepage string for the given LID.
  * 	Return value must be g_free ()'d
@@ -2187,7 +2227,7 @@ gsf_msole_lid_to_codepage_str (guint lid)
 }
 
 /**
- * gsf_msole_iconv_win_codepage :
+ * gsf_msole_iconv_win_codepage:
  *
  * Returns: our best guess at the applicable windows code page based on an
  * 	environment variable or the current locale.
@@ -2250,9 +2290,11 @@ gsf_msole_iconv_get_codepage_string_list (int codepage)
 }
 
 /**
- * gsf_msole_iconv_open_codepage_for_import :
- * @to:
- * @codepage :
+ * gsf_msole_iconv_open_codepage_for_import: (skip)
+ * @to: the target encoding.
+ * @codepage: the source code page.
+ *
+ * NOTE: skipped since GIConv is not exported to introspection.
  *
  * Returns: an iconv converter for @codepage -> utf8.
  **/
@@ -2281,8 +2323,10 @@ gsf_msole_iconv_open_codepage_for_import (char const *to, int codepage)
 }
 
 /**
- * gsf_msole_iconv_open_for_import :
- * @codepage :
+ * gsf_msole_iconv_open_for_import: (skip)
+ * @codepage: the source code page.
+ *
+ * NOTE: skipped since GIConv is not exported to introspection.
  *
  * Returns: an iconv converter for single byte encodings @codepage -> utf8.
  * 	Attempt to handle the semantics of a specification for multibyte encodings
@@ -2295,9 +2339,11 @@ gsf_msole_iconv_open_for_import (int codepage)
 }
 
 /**
- * gsf_msole_iconv_open_codepages_for_export :
- * @codepage_to :
- * @from :
+ * gsf_msole_iconv_open_codepages_for_export: (skip)
+ * @codepage_to: the target code page.
+ * @from: the source encoding.
+ *
+ * NOTE: skipped since GIConv is not exported to introspection.
  *
  * Returns: an iconv converter to go from utf8 -> to our best guess at a useful
  * 	windows codepage.
@@ -2327,8 +2373,10 @@ gsf_msole_iconv_open_codepages_for_export (int codepage_to, char const *from)
 }
 
 /**
- * gsf_msole_iconv_open_codepage_for_export :
- * @codepage_to:
+ * gsf_msole_iconv_open_codepage_for_export: (skip)
+ * @codepage_to: the target code page.
+ *
+ * NOTE: skipped since GIConv is not exported to introspection.
  *
  * Returns: an iconv converter to go from utf8 -> to our best guess at a useful
  * 	windows codepage.
@@ -2340,7 +2388,9 @@ gsf_msole_iconv_open_codepage_for_export (int codepage_to)
 }
 
 /**
- * gsf_msole_iconv_open_for_export :
+ * gsf_msole_iconv_open_for_export: (skip)
+ *
+ * NOTE: skipped since GIConv is not exported to introspection.
  *
  * Returns: an iconv convert to go from utf8 -> to our best guess at a useful
  * 	windows codepage.
@@ -2360,7 +2410,7 @@ gsf_msole_iconv_open_for_export (void)
  *
  * Decompresses an LZ compressed stream.
  *
- * Return value: A GByteArray that the caller is responsible for freeing
+ * Return value: (transfer full): A GByteArray that the caller is responsible for freeing
  **/
 GByteArray *
 gsf_msole_inflate (GsfInput *input, gsf_off_t offset)
@@ -2485,6 +2535,30 @@ gsf_msole_sorting_key_free (GsfMSOleSortingKey *sk)
 	}
 }
 
+static GsfMSOleSortingKey *
+gsf_ms_ole_sorting_key_copy (GsfMSOleSortingKey *sk)
+{
+	GsfMSOleSortingKey *res = g_new (GsfMSOleSortingKey, 1);
+	res->len = sk->len;
+	res->name = g_new (gunichar2, sk->len + 1);
+	memcpy (res->name, sk->name, (sk->len + 1) * sizeof (gunichar2));
+	return res;
+}
+
+GType
+gsf_msole_sorting_key_get_type (void)
+{
+    static GType type = 0;
+
+    if (type == 0)
+	type = g_boxed_type_register_static
+	    ("GsfMSOleSortingKey",
+	     (GBoxedCopyFunc) gsf_ms_ole_sorting_key_copy,
+	     (GBoxedFreeFunc) gsf_msole_sorting_key_free);
+
+    return type;
+}
+
 int
 gsf_msole_sorting_key_cmp (const GsfMSOleSortingKey *a,
 			   const GsfMSOleSortingKey *b)
