@@ -108,7 +108,7 @@ gsf_outfile_zip_finalize (GObject *obj)
 	g_free (zip->buf);
 
 	if (zip == zip->root)
-		gsf_vdir_free (zip->vdir, TRUE); /* Frees vdirs recursively */
+		gsf_zip_vdir_free (zip->vdir, TRUE); /* Frees vdirs recursively */
 
 	parent_class->finalize (obj);
 }
@@ -124,7 +124,7 @@ gsf_outfile_zip_constructor (GType                  type,
 					    construct_params));
 
 	if (!zip->entry_name) {
-		zip->vdir = gsf_vdir_new ("", TRUE, NULL);
+		zip->vdir = gsf_zip_vdir_new ("", TRUE, NULL);
 		zip->root_order = g_ptr_array_new ();
 		zip->root = zip;
 
@@ -592,7 +592,7 @@ gsf_outfile_zip_new_child (GsfOutfile *parent,
 						params);
 	gsf_property_settings_free (params, n_params);
 
-	child->vdir = gsf_vdir_new (name, is_dir, NULL);
+	child->vdir = gsf_zip_vdir_new (name, is_dir, NULL);
 
 	/* FIXME: It isn't clear what encoding name is in.  */
 	display_name = g_filename_display_name (name);
@@ -600,7 +600,7 @@ gsf_outfile_zip_new_child (GsfOutfile *parent,
 	g_free (display_name);
 
 	gsf_output_set_container (GSF_OUTPUT (child), parent);
-	gsf_vdir_add_child (zip_parent->vdir, child->vdir);
+	gsf_zip_vdir_add_child (zip_parent->vdir, child->vdir);
 	root_register_child (zip_parent->root, child);
 
 	return GSF_OUTPUT (child);
@@ -737,7 +737,7 @@ GSF_CLASS (GsfOutfileZip, gsf_outfile_zip,
 	   GSF_OUTFILE_TYPE)
 
 /**
- * gsf_outfile_zip_new :
+ * gsf_outfile_zip_new:
  * @sink: a #GsfOutput to hold the ZIP file
  * @err: Location to store error, or %NULL; currently unused.
  *
